@@ -21,6 +21,7 @@ class PythonPythonMapper(PythonMapperBase):
 
     language = "python"
     is_callable = False
+    member_order = 0
 
     def __init__(self, obj, class_content="class", **kwargs):
         super(PythonPythonMapper, self).__init__(obj, **kwargs)
@@ -139,8 +140,14 @@ class PythonPythonMapper(PythonMapperBase):
         skip_special_member = (
             self.is_special_member and "special-members" not in self.options
         )
+        skip_imported_member = self.imported and "imported-members" not in self.options
 
-        return skip_undoc_member or skip_private_member or skip_special_member
+        return (
+            skip_undoc_member
+            or skip_private_member
+            or skip_special_member
+            or skip_imported_member
+        )
 
     def _ask_ignore(self, skip):  # type: (bool) -> bool
         ask_result = self.app.emit_firstresult(
@@ -156,6 +163,7 @@ class PythonPythonMapper(PythonMapperBase):
 class PythonFunction(PythonPythonMapper):
     type = "function"
     is_callable = True
+    member_order = 40
 
     def __init__(self, obj, **kwargs):
         super(PythonFunction, self).__init__(obj, **kwargs)
@@ -180,6 +188,7 @@ class PythonFunction(PythonPythonMapper):
 class PythonMethod(PythonFunction):
     type = "method"
     is_callable = True
+    member_order = 50
 
     def __init__(self, obj, **kwargs):
         super(PythonMethod, self).__init__(obj, **kwargs)
@@ -211,6 +220,7 @@ class PythonData(PythonPythonMapper):
     """Global, module level data."""
 
     type = "data"
+    member_order = 10
 
     def __init__(self, obj, **kwargs):
         super(PythonData, self).__init__(obj, **kwargs)
@@ -236,6 +246,7 @@ class PythonAttribute(PythonData):
     """An object/class level attribute."""
 
     type = "attribute"
+    member_order = 10
 
 
 class TopLevelPythonPythonMapper(PythonPythonMapper):
@@ -290,6 +301,7 @@ class PythonPackage(TopLevelPythonPythonMapper):
 
 class PythonClass(PythonPythonMapper):
     type = "class"
+    member_order = 30
 
     def __init__(self, obj, **kwargs):
         super(PythonClass, self).__init__(obj, **kwargs)
@@ -374,3 +386,4 @@ class PythonClass(PythonPythonMapper):
 
 class PythonException(PythonClass):
     type = "exception"
+    member_order = 20
